Tutorials
=========

Basics:

.. toctree::
   :maxdepth: 1

   loading_river_networks
   xarray_array
   gridded_masked
   array_backend

Operations:

.. toctree::
   :maxdepth: 1

   computing_accumulations
   finding_catchments
   catchment_statistics
   distance_length
   creating_subnetworks
